package migl.lisp.util;

import java.math.BigInteger;

import migl.lisp.LispBoolean;

/**
 * Class pour gérer le parse des elements des expressions lisp
 * Utilisation d'une class pour éviter d'avoir un code smell sur sonar
 * 
 * @author Arthur Brandao
 */
public class LispElement<E> {

	/**
	 * La valeur de l'element
	 */
	public final E value;

	/**
	 * Constructeur privée pour construire un element à partir de valueOf
	 * @param val
	 */
	private LispElement(E val) {
		this.value = val;
	}

	/**
	 * Parse un element
	 * @param elt L'element à parser
	 * @return Un LispElement contenant la valeur extraite
	 */
	public static LispElement valueOf(String elt) {
		try {
			return new LispElement(new BigInteger(elt));
		} catch(NumberFormatException ex) {
			//Rien
		}
		try {
			return new LispElement(Double.valueOf(elt));
		} catch(NumberFormatException ex) {
			//Rien
		}
		try {
			return new LispElement(LispBoolean.valueOf(elt));
		} catch(IllegalArgumentException ex) {
			//Rien
		}
		return new LispElement(elt);
	}

}
